package com.example.simplevideoupload;

import java.io.File;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.StandardCopyOption;
import java.util.Locale;

import javax.servlet.annotation.WebServlet;

import com.vaadin.annotations.Theme;
import com.vaadin.annotations.VaadinServletConfiguration;
import com.vaadin.server.FileResource;
import com.vaadin.server.VaadinRequest;
import com.vaadin.server.VaadinService;
import com.vaadin.server.VaadinServlet;
import com.vaadin.ui.Button;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.Notification;
import com.vaadin.ui.UI;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.Video;

@SuppressWarnings("serial")
@Theme("simplevideoupload")
public class SimpleVideoUploadUI extends UI {
	
	static int nextVideoNo = 1; // counter to build final file name
	
	static String GAMEVIDEODIR = "\\video\\";
	
	private Button uploadButton = new Button("Upload video");
	private UploadComponent uploadVideoComp = null;
	private Button showButton = new Button("Show video");
	private Video videoArea = new Video();

	@WebServlet(value = "/*", asyncSupported = true)
	@VaadinServletConfiguration(productionMode = false, ui = SimpleVideoUploadUI.class)
	public static class Servlet extends VaadinServlet {
	}

	@Override
	protected void init(VaadinRequest request) {
		final VerticalLayout layout = new VerticalLayout();
		layout.setMargin(true);
		setContent(layout);
		
		Locale.setDefault(Locale.Category.FORMAT,Locale.ENGLISH);

		HorizontalLayout hl = new HorizontalLayout();
		layout.addComponent(hl);
		uploadButton.addClickListener(this::onUploadVideo);
		hl.addComponent(uploadButton);
		
		showButton.addClickListener(this::onShowVideo);
		hl.addComponent(showButton);
		
		layout.addComponent(videoArea);
		videoArea.setVisible(false);
		videoArea.setAltText("altText");
		
		this.uploadVideoComp = new UploadComponent();
		uploadVideoComp.setSession(this.getSession());
		uploadVideoComp.setParent(this);
		uploadVideoComp.buildLayout();
	}
	
	void onShowVideo(ClickEvent event)
	{
		String filename = VaadinService.getCurrent().getBaseDirectory().getAbsolutePath()
				+ GAMEVIDEODIR
				+ (nextVideoNo - 1)
				+ "."
				+ "mp4";
		File file = new File(filename);
		if(file.exists()) // CR00054
		{
			videoArea.setHtmlContentAllowed(false);
			videoArea.setVisible(true);
			FileResource fr = new FileResource(file);
			videoArea.setSource(fr);
		} else {
			this.videoArea.setHtmlContentAllowed(true);
			videoArea.setSource(null);
		}
	}

	void onUploadVideo(ClickEvent event)
	{
		this.uploadVideoComp.initUploadFile();
		this.getUI().addWindow(this.uploadVideoComp.getUploadWND());
		
	}

	void onExecImport(ClickEvent event)
	{
		File file = uploadVideoComp.getFupl().getFile();
		String dateiname1 = file.getName();
		String fileExtension = null;
		dateiname1 = dateiname1.replace('.', ':'); // da . in RegEx "all characters" bedeutet
		String[] splitted = dateiname1.split(":");
		int length = splitted.length;
		if(length > 0)
			fileExtension=splitted[length-1];
		
		String basepath = VaadinService.getCurrent().getBaseDirectory().getAbsolutePath();
		File toFile = new File(basepath + GAMEVIDEODIR + nextVideoNo + "." + fileExtension );
		Path fromPath = file.toPath();
		Path toPath = toFile.toPath();
		try {
			Files.move( fromPath
					, toPath
					, StandardCopyOption.REPLACE_EXISTING
					);
			nextVideoNo++;
		} catch (Exception e) {
			Notification.show("Error", e.getMessage(), Notification.Type.ERROR_MESSAGE);
		} 
	}
}