package com.example.simplevideoupload;

import java.io.File;
import com.vaadin.server.FileResource;
import com.vaadin.server.VaadinSession;
import com.vaadin.ui.Button;
import com.vaadin.ui.Component;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.Notification;
import com.vaadin.ui.Upload;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.Video;
import com.vaadin.ui.Window;


public class UploadComponent extends VerticalLayout {

	private static final long serialVersionUID = 1L;
	private FileUploader fupl = null;
	private Upload uploadComp = null;
	private Video videoArea = null;
	private Button ExecImportButton = new Button();
	private Button CancelImportBildButton = new Button();
	private Window uploadWND = null;
	private VaadinSession Session = null;
	
	private SimpleVideoUploadUI parent = null;

	public UploadComponent() {
	}

	public UploadComponent(Component... children) {
		super(children);
	}
	public void buildLayout()
	{
		this.setMargin(true);

		uploadWND = new Window(null,this); 
		uploadWND.setModal(true);
		uploadWND.center();
		uploadWND.setClosable(false);
		uploadWND.setResizable(false);
		uploadWND.setDraggable(true);
		uploadWND.setCaption("Upload video");

		fupl = new FileUploader(this,Session);
		uploadComp = new Upload(null,fupl);
		uploadComp.addSucceededListener(fupl);
		this.addComponent(uploadComp);
		
		videoArea = new Video();
		videoArea.setWidth(800, Unit.PIXELS);
		videoArea.setHeight(500, Unit.PIXELS );
		videoArea.setAutoplay(false);
		videoArea.setShowControls(true);
		videoArea.setMuted(false);
		this.addComponent(videoArea);
		
		HorizontalLayout hl = new HorizontalLayout();
		this.addComponent(hl);
		
		hl.addComponent(this.ExecImportButton);
		ExecImportButton.setCaption("Exec import");
		ExecImportButton.addClickListener(this::onExecImport);
		ExecImportButton.addClickListener(parent::onExecImport);
		hl.addComponent(this.CancelImportBildButton);
		this.CancelImportBildButton.addClickListener(this::onUploadCancel);
		CancelImportBildButton.setCaption("Cancel");
	
	}
	void showUploadedFile(String filename)
	{ 
		
		File file = new File(filename);

		String mimetype = fupl.getMimeType();
		try {
			if(mimetype != null) 
			{
				if(mimetype.startsWith("video"))
				{
					this.videoArea.setHtmlContentAllowed(false);
					FileResource fr = new FileResource(file);
					videoArea.setSource(fr);
					/*
					String mt = fr.getMIMEType();
					videoArea.setSource(streamresource);
					*/
					this.enableImportExec();
				}
			} else {
				throw new Exception("MIME type missing");
			}

		} catch (Exception e) {
			Notification.show("Error", e.getMessage(), Notification.Type.ERROR_MESSAGE);
		}
	}
	public void initUploadFile()
	{
		this.ExecImportButton.setEnabled(false);
	}
	protected void onExecImport(Button.ClickEvent event)
	{
		if(videoArea != null)
		{
			this.videoArea.setHtmlContentAllowed(true);
			this.videoArea.setSource(null);
		}
		this.getUI().removeWindow(uploadWND);
	}
	private void onUploadCancel(Button.ClickEvent event)
	{
		this.getUI().removeWindow(uploadWND);
		if(videoArea != null)
		{
			this.videoArea.setHtmlContentAllowed(true);
			this.videoArea.setSource(null);
		}
		this.ExecImportButton.setEnabled(false);
	}
	public void enableImportExec() {
		ExecImportButton.setEnabled(true);
	}
	public void prepareUpload() {
		ExecImportButton.setEnabled(false);
	}

	public void setSession(VaadinSession session)
	{
		this.Session = session;
	}

	public void setParent(SimpleVideoUploadUI parent) { // CR00042
		this.parent = parent;
	}

	public FileUploader getFupl() {
		return fupl;
	}

	public Window getUploadWND() {
		return uploadWND;
	}
}
